Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/django_global_search/__init__.py | 2 | 0 | 0 | 100%
src/django_global_search/admin.py | 17 | 0 | 0 | 100%
src/django_global_search/apps.py | 12 | 1 | 0 | 92%
src/django_global_search/permissions.py | 24 | 0 | 4 | 100%
src/django_global_search/searcher.py | 116 | 6 | 3 | 95%
src/django_global_search/settings.py | 27 | 0 | 0 | 100%
src/django_global_search/views.py | 103 | 7 | 0 | 93%
Total | 301 | 14 | 7 | 95%

No items found using the specified filter.